@@ -2,7 +2,6 @@
 
 this do some stuff
 """
-# vim: ts=4 sw=4 et
 import argparse
 import os
 from urllib.parse import urlparse
@@ -37,8 +36,7 @@ def is_dir(dirname):
     if not os.path.isdir(dirname):
         msg = f"{dirname} is not a directory"
         raise argparse.ArgumentTypeError(msg)
-    else:
-        return dirname
+    return dirname
 
 
 def can_create_dir(path):
@@ -53,11 +51,9 @@ def can_create_dir(path):
     parts = os.path.split(path)
     if os.path.exists(parts[0]):
         return True
-    else:
-        if not parts[1] == '':
-            return can_create_dir(parts[0])
-        else:
-            return False
+    if not parts[1] == '':
+        return can_create_dir(parts[0])
+    return False
 
 
 def is_searchable_file(path):
@@ -130,14 +126,13 @@ def is_valid_dir(path):
         _type_: _description_
     """
     path = expand_path(path)
-    if is_dir(path):
+    if os.path.isdir(path):
         return path
-    else:
-        # is not a directory, verify file
-        if not os.path.exists(path):
-            # path dont exist, check if can be create
-            if can_create_dir(path):
-                return path
+    # is not a directory, verify file
+    if not os.path.exists(path):
+        # path dont exist, check if can be create
+        if can_create_dir(path):
+            return path
     raise argparse.ArgumentTypeError(
         f"{path} is not a valid directory path")
 
@@ -187,14 +182,6 @@ def is_readable(path):
     return os.access(path, os.R_OK)
 
 
-class FullPaths(argparse.Action):
-    """Expand user- and relative-paths"""
-
-    def __call__(self, parser, namespace, values, option_string=None):
-        setattr(namespace, self.dest, os.path.abspath(
-            os.path.expanduser(values)))
-
-
 class FileFinder:
     """_summary_
 
@@ -211,12 +198,12 @@ class FileFinder:
         paths = []
         self.fname = expand_path(self.fname)
         if os.path.isfile(self.fname) and is_readable(self.fname):
-            with open(self.fname, mode='r', encoding='utf-8') as fp:
-                for line in fp:
-                    ln = line.strip()
+            with open(self.fname, mode='r', encoding='utf-8') as file:
+                for line in file:
+                    line = line.strip()
                     if line.strip() == "":
                         continue
-                    if any(map(lambda x: ln.startswith(x), FileFinder.COMMENTS)):
+                    if any(map(line.startswith, FileFinder.COMMENTS)):
                         continue  # is a comment, ignore line
                     path = os.path.abspath(os.path.expanduser(
                         os.path.expandvars(line.strip())))
